@@ -72,6 +72,25 @@ class AdselTest(TestCase):
         self.assertEqual(len(applications), 4)
         self.assertEqual(applications[0].adsel_id, 1)
 
+    def test_get_applications_by_syskey_list(self):
+        # No Match
+        applications = self.adsel.get_applications_by_qtr_syskey_list(0,
+                                                                      [123])
+        self.assertEqual(len(applications), 0)
+        # Partial Match
+        applications = self.adsel.get_applications_by_qtr_syskey_list(0,
+                                                                      [123,
+                                                                       76711,
+                                                                       656340])
+        self.assertEqual(len(applications), 2)
+        # Full Match
+        applications = self.adsel.get_applications_by_qtr_syskey_list(0,
+                                                                      [456340,
+                                                                       97508,
+                                                                       156340,
+                                                                       76711])
+        self.assertEqual(len(applications), 6)
+
     def test_post(self):
         a1 = Application()
         a1.adsel_id = 123
